******** Beginning of example3.do **********************************************
/*
  Demonstrate the use of -sencode- and -decode- to create plots and tables
  from a -parmby- resultsset with the -label- option.
  Unofficial Stata packages required:
  -somersd-, -parmest-, -sencode-. -sdecode-, -eclplot-, -listtex-.
*/

version 8.0

set scheme s1mono

sysuse auto, clear

/*
  Create a -parmby- resultsset of Somers' D parameters
*/

parmby ///
  "somersd foreign price mpg headroom trunk weight length turn displacement gear_ratio" ///
  , label norestore format(estimate min95 max95 %8.2f p %-8.2g)
more
describe
more
list parm label estimate min95 max95, noobs
more

/*
  Convert string variable -label- to numeric variable -predictor-
*/

sencode label, gsort(estimate parmseq) gene(predictor)
label variable predictor "Predictor of non-US origin"
label list predictor
more

/*
  Plot confidence intervals against numeric variable -predictor-
*/

eclplot estimate min95 max95 predictor, horizontal ///
  yscale(range(0 10)) ylabel(1(1)9, notick) ///
  xlabel(-1(0.25)1) xline(0, lpattern(shortdash)) ///
  xtitle("Somers' D (95% CI)") ///
  estopts(mcolor(black) msize(large)) ///
  ciopts(msize(huge) blcolor(black))
* To save Figure 2 to disk, insert the line:
* graph save figure2, replace
more

/*
 Convert numeric confidence limit variables
 to string variables with parentheses
*/

sdecode min95, replace
sdecode max95, replace
replace min95="("+min95+","
replace max95=max95+")"
sort predictor
list predictor estimate min95 max95
more

/*
 Create a table to be cut and pasted
 into a Microsoft Word document
*/

listtex predictor estimate min95 max95, headline("Predictor&Somers' D&(95%&CI)") type
more

exit
******** End of example3.do ****************************************************
